# Changelog

## v0.1.0

  * First release of BDTsim simulation tool
  * First supported protocol (also used for internal teste) with two variants
    * [SimplePayment](https://gitlab.mlohr.com/bdtsim/protocols/#simplepayment) (direct and indirect payment)
  * Supported environments:
    * [PyEVM](https://gitlab.mlohr.com/bdtsim/environments/#pyevm)
    * [Web3HTTP](https://gitlab.mlohr.com/bdtsim/environments/#web3http)
    * [Web3Websocket](https://gitlab.mlohr.com/bdtsim/environments/#web3socket)
    * [Web3IPC](https://gitlab.mlohr.com/bdtsim/environments/#web3ipc)
